@@ -11,6 +11,7 @@ from elasticutils._version import __version__  # noqa
 log = logging.getLogger('elasticutils')
 
 
+# Note: Don't change these--they're not part of the API.
 DEFAULT_URLS = ['http://localhost:9200']
 DEFAULT_DOCTYPES = None
 DEFAULT_INDEXES = None
@@ -181,6 +182,33 @@ def _process_facets(facets, flags):
     return rv
 
 
+def _facet_counts(items):
+    """Returns facet counts as dict.
+
+    Given the `items()` on the raw dictionary from Elasticsearch this processes
+    it and returns the counts keyed on the facet name provided in the original
+    query.
+
+    """
+    facets = {}
+    for key, val in items:
+        if val['_type'] == 'terms':
+            facets[key] = [v for v in val['terms']]
+        elif val['_type'] == 'range':
+            facets[key] = [v for v in val['ranges']]
+        elif val['_type'] == 'histogram':
+            facets[key] = [v for v in val['entries']]
+        elif val['_type'] == 'date_histogram':
+            facets[key] = [v for v in val['entries']]
+        elif val['_type'] in ('filter', 'query', 'statistical'):
+            facets[key] = val
+        else:
+            raise InvalidFacetType(
+                'Facet _type "%s". key "%s" val "%r"' %
+                (val['_type'], key, val))
+    return facets
+
+
 class F(object):
     """
     Filter objects.
@@ -592,7 +620,9 @@ class S(PythonMixin):
                     .order_by('-title')
 
 
-        You can also sort by the computed field ``_score``.
+        You can also sort by the computed field ``_score`` or pass a dict as
+        a sort field in order to use more advanced sort options.  Read the
+        Elasticsearch documentation for details.
 
         .. Note::
 
@@ -944,7 +974,7 @@ class S(PythonMixin):
             if action == 'order_by':
                 sort = []
                 for key in value:
-                    if key.startswith('-'):
+                    if isinstance(key, basestring) and key.startswith('-'):
                         sort.append({key[1:]: 'desc'})
                     else:
                         sort.append(key)
@@ -1249,7 +1279,7 @@ class S(PythonMixin):
         Perform the search, then convert that raw format into a
         SearchResults instance and return it.
         """
-        if not self._results_cache:
+        if self._results_cache is None:
             response = self.raw()
             ResultsClass = self.get_results_class()
             results = self.to_python(response.get('hits', {}).get('hits', []))
@@ -1440,23 +1470,7 @@ class S(PythonMixin):
         >>> facet_counts = s.facet_counts()
 
         """
-        facets = {}
-        for key, val in self._raw_facets().items():
-            if val['_type'] == 'terms':
-                facets[key] = [v for v in val['terms']]
-            elif val['_type'] == 'range':
-                facets[key] = [v for v in val['ranges']]
-            elif val['_type'] == 'histogram':
-                facets[key] = [v for v in val['entries']]
-            elif val['_type'] == 'date_histogram':
-                facets[key] = [v for v in val['entries']]
-            elif val['_type'] == 'statistical':
-                facets[key] = val
-            else:
-                raise InvalidFacetType(
-                    'Facet _type "%s". key "%s" val "%r"' %
-                    (val['_type'], key, val))
-        return facets
+        return _facet_counts(self._raw_facets().items())
 
 
 class MLT(PythonMixin):
@@ -1573,7 +1587,7 @@ class MLT(PythonMixin):
         Perform the mlt call, then convert that raw format into a
         SearchResults instance and return it.
         """
-        if not self._results_cache:
+        if self._results_cache is None:
             response = self.raw()
             results = self.to_python(response.get('hits', {}).get('hits', []))
             self._results_cache = DictSearchResults(
@@ -1617,6 +1631,7 @@ class SearchResults(object):
         self.response = response
         self.took = response.get('took', 0)
         self.count = response.get('hits', {}).get('total', 0)
+        self.facets = _facet_counts(response.get('facets', {}).items())
         self.results = results
         self.fields = fields
 
